@@ -15,7 +15,7 @@ use Apache::Constants qw(:common REDIRECT);
 use Apache::File ();
 
 our $WIN32 = $^O =~ /win32/i;
-our $VERSION = do { my @r = (q$Revision: 0.04 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 0.05 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 # Constructor
 ################################################################################
@@ -104,11 +104,6 @@ sub new {
 sub import {
   my $package = (caller())[0];
   my $dir = $_[1];
-
-  open OUT, ">>/usr/web/jaf.webzavod.ru/scripts/import.out";
-  print OUT "$package => $dir\n\n";
-  close OUT;
-
   load_handlers(undef, $package, $dir) if $dir && $package ne __PACKAGE__;
 }
 
@@ -263,7 +258,7 @@ sub handler ($$) {
     } else {
       #
       # if handler set $self->{type} other than text/(html|plain)
-      # then data must be send to client by on_send_... method
+      # then data must be send to the client by on_send_..._data method
       #
       my $method = "on_send_${\($self->{handler})}_data";
       $self->$method(@{$self->{uri}}) if $self->can($method);
@@ -466,7 +461,7 @@ Apache::JAF -- mod_perl and Template-Toolkit web applications framework
    return OK;
  }
 
-=item modeller -- module that encapsulates application business-logic
+=item modeller -- the module that encapsulates application business-logic
 
  package JAF::MyJAF;
  use strict;
@@ -492,9 +487,9 @@ Apache::JAF -- mod_perl and Template-Toolkit web applications framework
     SetHandler perl-script
     PerlHandler Apache::JAF::MyJAF
     PerlSetVar Apache_JAF_Templates /examples/site/templates
-    # optional -- default value is shown
+    # optional -- default value is used in example
     PerlSetVar Apache_JAF_Modules /examples/site/modules/Apache/JAF/MyJAF/pages
-    # optional -- default value is shown
+    # optional -- default value is used in example
     PerlSetVar Apache_JAF_Compiled /tmp
   </Location>
 
@@ -596,21 +591,110 @@ dynamic generation of images, M$ Excel workbooks and any other type of data.
 
 =back
 
-=head2 Apache::JAF descendant methods
+=head2 Apache::JAF methods
 
 =over 4
 
 =item setup_handler
 
+This method you must override in your Apache::JAF descendant. You must return handler 
+name (that later will be called as I<do_E<lt>handler nameE<gt>> method) from it depending 
+on uri user requested. You may set site-wide properties such as I<debug_level>, I<header> 
+or I<footer>, templates and includes extensions and so on. If handler name depends on 
+application logic implemented in modeller you have to create modeller in this method 
+and store it in I<m> property for later use.
+The simpliest I<setup_handler> is shown in L<"SYNOPSIS">.
+
 =item site_handler
 
+You can override this method to provide common tasks for each of your page-handlers. For
+example you may create instance of modeller class, provide some custom 
+authorization/authentication or sessions handling and so on. You must call 
+C<$selfE<gt>SUPER::site_handler> and return C<$self-E<gt>{status}> from it.
+
+=back
+
+=head2 Apache::JAF properties
+
+=over 4
+
+=item r
+
+Current C<Apache::Request> object.
+
+=item filter
+
+Using C<Apache::Filter> flag.
+
+=item uri
+
+Reference to the array of current uri (splitted by slash). Usually you will need modify
+it in L<"setup_handler"> method to determine page-handler name. Remained array will be passed
+to the page-handler method as parameters list.
+
+=item res
+
+Hash reference that holds page-handler results.
+
+=item expand_path
+
+Boolean flag for complex-name-handlers change '/' in handler name in place of '_' to 
+provide real-like document tree in the templates folder.
+
+=item debug_level
+
+Look at B<Apache_JAF_Debug> in L<"CONFIGURATION"> section.
+
+=item status
+
+Default handler status is C<NOT_FOUND>.
+
+=item type
+
+Default content-type is C<text/html>.
+
+=item template_ext, include_ext
+
+Default template extension is C<.html>.
+Default include template extension is C<.inc>.
+
+=item default_include
+
+Site-wide include template. Default value is... C<default>.
+
+=item header, footer
+
+Site-wide pre- and post-include templates. Defalut values are C<header> and C<footer>.
+I<Note:>You must undef this properies if you want create page-template without it. For
+example for page in pop-up window.
+
+=item templates
+
+Path to the templates folder. You may have different sets of templates for different
+views of results generated by your page-handlers.
+
+=item handler
+
+Result of C<setup_handler> method is stored here for later use.
+
+=item I<other properites>
+
+For internal use only.
+
 =back
 
 =head2 Implementing handlers
 
+Page handlers are simple. It's methods with C<do_E<lt>handler nameE<gt>> name. You have to
+analyse given parameters, fill out C<$self-E<gt>{res}> hash with handler results that will 
+be processed with template and return one of the C<Apache::Constants>. Usually it's C<OK>, 
+but may be C<NOT_FOUND> if parameters passed to handlers are invalid for some reason.
+
+Look into F<examples/*> folder in the distribution package for some guidelines.
+
 =head2 Templates structure and syntax
 
-Template for specific handler consists of:
+Template for a specific handler consists of:
 
 =over 4
 
